use Test::Spec;

use File::Temp qw{tempfile};
use Path::Class;
use Tails::Persistence::Utils qw{get_variable_from_file};

describe 'A file' => sub {
    my ($fh, $file);
    before sub {
        ($fh, $file) = tempfile();
        print $fh '';
        close $fh;
    };
    describe 'that contains "a=b" on the first line' => sub {
        before sub {
            my $fh = file($file)->openw;
            print $fh "a=b\n";
        };
        it 'has value "b" for variable "a"' => sub {
            is(get_variable_from_file($file, "a"), "b");
        };
    };
    describe 'that contains "  a=b" on the first line' => sub {
        before sub {
            my $fh = file($file)->openw;
            print $fh "  a=b\n";
        };
        it 'has value "b" for variable "a"' => sub {
            is(get_variable_from_file($file, "a"), "b");
        };
    };
    describe 'that contains "a=b" on the second line' => sub {
        before sub {
            my $fh = file($file)->openw;
            print $fh "bla\na=b\n";
        };
        it 'has value "b" for variable "a"' => sub {
            is(get_variable_from_file($file, "a"), "b");
        };
    };
    describe 'that contains "a = b"' => sub {
        before sub {
            my $fh = file($file)->openw;
            print $fh "a = b\n";
        };
        it 'has no value for variable "a"' => sub {
            ok(! defined(get_variable_from_file($file, "a")));
        };
    };
};

runtests unless caller;
